const handler = async ({ request }: { request: Request }) => {
    // Log the HTTP method
    console.log('HTTP Method:', request.method);

    // Log the full URL
    console.log('URL:', request.url);

    // Log request headers
    console.log('Headers:', Object.fromEntries(request.headers.entries()));

    // Log the body, depending on its content type
    const contentType = request.headers.get('content-type') || '';

    if (contentType.includes('application/json')) {
        const jsonBody = await request.json();
        console.log('JSON Body:', JSON.stringify(jsonBody, null, 2));
    } else if (contentType.includes('application/x-www-form-urlencoded')) {
        const formData = await request.formData();
        const formObject: Record<string, string> = {};
        formData.forEach((value, key) => {
            formObject[key] = value.toString();
        });
        console.log('Form Data:', formObject);
    } else if (contentType.includes('multipart/form-data')) {
        const formData = await request.formData();
        const formObject: Record<string, string> = {};
        formData.forEach((value, key) => {
            formObject[key] = value.toString();
        });
        console.log('Multipart Form Data:', formObject);
    } else {
        const textBody = await request.text();
        console.log('Text Body:', textBody);
    }

    return new Response('Request logged!', { status: 200 });
};

// Bind the handler to all HTTP methods
export const GET = handler;
export const POST = handler;
export const PUT = handler;
export const DELETE = handler;
export const PATCH = handler;
export const OPTIONS = handler;
